# coding: utf-8

"""
    Dropbox Sign API

    Dropbox Sign v3 API

    The version of the OpenAPI document: 3.0.0
    Contact: apisupport@hellosign.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class SubFormFieldsPerDocumentFontEnum(str, Enum):
    """
    SubFormFieldsPerDocumentFontEnum
    """

    """
    allowed enum values
    """
    HELVETICA = "helvetica"
    ARIAL = "arial"
    COURIER = "courier"
    CALIBRI = "calibri"
    CAMBRIA = "cambria"
    GEORGIA = "georgia"
    TIMES = "times"
    TREBUCHET = "trebuchet"
    VERDANA = "verdana"
    ROBOTO = "roboto"
    ROBOTOMONO = "robotoMono"
    NOTOSANS = "notoSans"
    NOTOSERIF = "notoSerif"
    NOTO_CJK_MINUS_JP_MINUS_REGULAR = "notoCJK-JP-Regular"
    NOTO_HEBREW_MINUS_REGULAR = "notoHebrew-Regular"
    NOTOSANTHAIMERGED = "notoSanThaiMerged"

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of SubFormFieldsPerDocumentFontEnum from a JSON string"""
        return cls(json.loads(json_str))
